import { registerDataType } from '../vendors/organik';
import { BuiltInDataType } from '../types/data-type';
import { isBoolean, isNumber, isString, isArray, isPlainObject } from '../utils';
const numberDescriptor = {
    validator: isNumber,
    defaultValueGetter: () => 0,
};
const stringDescriptor = {
    validator: isString,
    defaultValueGetter: () => '',
};
const listDescriptor = {
    validator: isArray,
    defaultValueGetter: () => [],
};
const objectDescriptor = {
    validator: isPlainObject,
    defaultValueGetter: () => ({}),
};
function isEnumValue(value) {
    return isNumber(value) || isString(value);
}
[
    { name: BuiltInDataType.Boolean, validator: isBoolean, defaultValueGetter: () => false },
    Object.assign({ name: BuiltInDataType.Integer }, numberDescriptor),
    Object.assign({ name: BuiltInDataType.Float }, numberDescriptor),
    Object.assign({ name: BuiltInDataType.String }, stringDescriptor),
    Object.assign({ name: BuiltInDataType.Text }, stringDescriptor),
    { name: BuiltInDataType.Enum, validator: isEnumValue, defaultValueGetter: () => '' },
    {
        name: BuiltInDataType.MultiEnum,
        validator: value => isArray(value) && value.every(isEnumValue),
        defaultValueGetter: () => [],
    },
    Object.assign({ name: BuiltInDataType.OneToOne }, objectDescriptor),
    Object.assign({ name: BuiltInDataType.OneToMany }, listDescriptor),
    Object.assign({ name: BuiltInDataType.ManyToMany }, listDescriptor),
    Object.assign({ name: BuiltInDataType.ManyToOne }, objectDescriptor),
].forEach(registerDataType);
