import { clone } from '@ntks/toolbox';
import EventEmitter from '@ntks/event-emitter';
class ValueContext extends EventEmitter {
    constructor({ defaultValue, initialValue }) {
        super();
        this.valueInited = false;
        this.defaultValue = clone(defaultValue);
        this.value = initialValue ? clone(initialValue) : clone(defaultValue);
    }
    getDefaultValue() {
        return clone(this.defaultValue);
    }
    getValue() {
        return clone(this.value);
    }
    setValue(value) {
        this.value = clone(value);
        this.emit('change', this.getValue());
        if (!this.valueInited) {
            this.valueInited = true;
            this.emit('ready');
        }
    }
    isReady() {
        return this.valueInited;
    }
    submit() {
        this.emit('submit');
    }
    reset() {
        this.setValue(this.getDefaultValue());
        this.emit('reset', this.getValue());
    }
}
export { ValueContext };
