import { __awaiter } from "tslib";
import { isPlainObject, pick, clone } from '@ntks/toolbox';
import { createSearchContext, resolveListRequestParams, createViewContext, } from '../../core';
import { ViewContext } from './base';
class ListViewContext extends ViewContext {
    constructor(moduleContext, options) {
        super(moduleContext, Object.assign(Object.assign({}, options), { defaultValue: [] }));
        this.searchCondition = {};
        this.dataSourceInited = false;
        this.children = [];
        this.totalPage = 0;
        this.currentPage = 0;
        this.currentPageSize = 0;
        const { search } = options;
        this.search = search;
        this.childrenCreator = (data) => data.map(record => createViewContext(moduleContext, {
            name: `ObjectViewIn${options.name}`,
            category: 'object',
            widget: '',
            fields: this.getFields(),
            actions: this.getActionsByContextType('single'),
            initialValue: record,
            parent: this,
        }));
        this.conditionInited = !search;
        this.shorthandNames = pick(options, ['getList', 'deleteOne', 'deleteList']);
        if (isPlainObject(search)) {
            const searchContext = createSearchContext(search, moduleContext.getModel());
            const loadData = () => this.setCurrentPage(1);
            searchContext.on({
                change: value => (this.searchCondition = value),
                filterChange: ({ name, value }) => (this.searchCondition[name] = value),
                ready: () => (this.conditionInited = true),
                submit: loadData,
                reset: loadData,
            });
            this.searchContext = searchContext;
        }
    }
    getChildren() {
        return this.children;
    }
    getSearch() {
        return this.search;
    }
    getSearchContext() {
        return this.searchContext;
    }
    getTotal() {
        return this.totalPage;
    }
    getCurrentPage() {
        return this.currentPage;
    }
    setCurrentPage(current, silent) {
        const changed = this.currentPage !== current;
        this.currentPage = current;
        if (silent !== true) {
            if (changed) {
                this.emit('currentPageChange', current);
            }
            this.load();
        }
    }
    getPageSize() {
        return this.currentPageSize;
    }
    setPageSize(size, silent) {
        const changed = this.currentPageSize !== size;
        this.currentPageSize = size;
        if (silent !== true) {
            if (changed) {
                this.emit('pageSizeChange', size);
            }
            this.load();
        }
    }
    setDataSource(data) {
        const copy = clone(data);
        super.setDataSource(copy);
        this.children = this.childrenCreator(copy);
        if (!this.dataSourceInited) {
            this.dataSourceInited = true;
        }
        this.emit('dataChange', data);
    }
    load() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.conditionInited) {
                return;
            }
            this.setBusy(true);
            this.getList(resolveListRequestParams(this.searchCondition, this.currentPage, this.currentPageSize), (data, { total }) => {
                this.setDataSource(data);
                this.totalPage = total;
                this.emit('totalChange', total);
            }).finally(() => this.setBusy(false));
        });
    }
    reload() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.load();
        });
    }
    getList(params, success, fail) {
        return this.getModuleContext().execute(this.shorthandNames.getList || 'getList', params, success, fail);
    }
    deleteOne(params, success, fail) {
        return this.getModuleContext().execute(this.shorthandNames.deleteOne || 'deleteOne', params, success, fail);
    }
    deleteList(params, success, fail) {
        return this.getModuleContext().execute(this.shorthandNames.deleteList || 'deleteList', params, success, fail);
    }
}
export { ListViewContext };
