import { clone } from '@ntks/toolbox';
import { createEventEmitter } from './event';
function createValueContext(options) {
    const { on, off, emit } = createEventEmitter();
    const defaultValue = clone(options.defaultValue);
    const getDefaultValue = () => clone(defaultValue);
    let value = options.initialValue ? clone(options.initialValue) : getDefaultValue();
    let valueInited = false;
    const getValue = () => clone(value);
    const setValue = (newValue) => {
        value = clone(newValue);
        emit('change', getValue());
        if (!valueInited) {
            valueInited = true;
            emit('ready');
        }
    };
    return {
        getDefaultValue,
        getValue,
        setValue,
        isReady: () => valueInited,
        submit: () => emit('submit'),
        reset: () => {
            setValue(getDefaultValue());
            emit('reset', value);
        },
        on,
        off,
        emit,
    };
}
export { createValueContext };
