import { mixin } from '@ntks/toolbox';
import { resolveFieldMap } from '../../model';
const viewContextMap = new Map();
function getViewContext(id) {
    return viewContextMap.get(id);
}
function setViewContext(viewContext) {
    const id = viewContext.getId();
    if (viewContextMap.has(id)) {
        return;
    }
    viewContextMap.set(id, viewContext);
}
function resolveFields(fields, model) {
    if (!model) {
        return fields;
    }
    const fieldMap = resolveFieldMap(model.fields);
    return fields.map(field => fieldMap[field.name]
        ? mixin(true, {}, fieldMap[field.name], field)
        : field);
}
function runExpression({ dataSource, value }, expression, defaultReturnValue) {
    const func = new Function('$dataSource', '$value', `return ${expression}`); // eslint-disable-line no-new-func
    let result;
    try {
        result = func.call(null, dataSource, value); // eslint-disable-line no-useless-call
    }
    catch (err) {
        console.error(err);
        result = defaultReturnValue;
    }
    return result;
}
export { resolveFields, runExpression, getViewContext, setViewContext };
